/*
 * jammo-chum.c
 *
 * This file is part of JamMo.
 *
 * (c) 2009 University of Oulu
 *
 * Authors: Henrik Hedberg <henrik.hedberg@oulu.fi>
 */

#include "jammo-chum.h"
#include <tangle.h>

void jammo_chum_init(int* argc, char** argv[]) {
	tangle_init(argc, argv);
}
